@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 1996-2012 Free Software Foundation, Inc.
+# Copyright (C) 1996-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 # Yet another canonicalization test.
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -31,6 +31,6 @@ END
 $ACLOCAL
 $AUTOMAKE
 
-$FGREP 'perm_number.c' Makefile.in && Exit 1
+$FGREP 'perm_number.c' Makefile.in && exit 1
 
 :
