@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 1996-2012 Free Software Foundation, Inc.
+# Copyright (C) 1996-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 # Check to make sure EXTRA_foo_SOURCES not defined unnecessarily.
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -29,5 +29,5 @@ END
 $ACLOCAL
 $AUTOMAKE
 
-grep EXTRA_foo_SOURCES Makefile.in && Exit 1
-Exit 0
+grep EXTRA_foo_SOURCES Makefile.in && exit 1
+exit 0
