@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2010-2012 Free Software Foundation, Inc.
+# Copyright (C) 2010-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,9 @@
 
 # Check for bug in variable concatenation with '+=': an extra backslash
 # is erroneously retained in the final value.
-# See also sister test pluseq11b.test.
+# See also sister test 'pluseq11b.sh'.
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >>configure.ac <<'END'
 AC_OUTPUT
@@ -43,7 +43,7 @@ END
 $ACLOCAL
 $AUTOMAKE
 
-grep '^ *FOO *=.*\\.' Makefile.in && Exit 1
+grep '^ *FOO *=.*\\.' Makefile.in && exit 1
 
 $AUTOCONF
 ./configure
